Launcher

Struct Launcher 

pub struct Launcher;
The type corresponding to the Launcher protocol. A low-level interface for launching processes.

This interface is used for manually assembling a process. The caller supplies all the capabilities for the newly created process.

That create processes typically use fdio_spawn or fdio_spawn_etc rather than using this interface directly. The fdio_spawn and fdio_spawn_etc functions are implemented using this interface.

Debuggers and other clients that need to create processes in a suspended state often use this interface directly. These clients use the CreateWithoutStarting method to create the process without actually starting it.