LauncherLocalServerHandler

Trait LauncherLocalServerHandler 

pub trait LauncherLocalServerHandler<___T: Transport = Channel> {
    // Required methods
    fn launch(
        &mut self,
        request: Request<Launch, ___T>,
        responder: Responder<Launch, ___T>,
    ) -> impl Future<Output = ()>;
    fn create_without_starting(
        &mut self,
        request: Request<CreateWithoutStarting, ___T>,
        responder: Responder<CreateWithoutStarting, ___T>,
    ) -> impl Future<Output = ()>;
    fn add_args(
        &mut self,
        request: Request<AddArgs, ___T>,
    ) -> impl Future<Output = ()>;
    fn add_environs(
        &mut self,
        request: Request<AddEnvirons, ___T>,
    ) -> impl Future<Output = ()>;
    fn add_names(
        &mut self,
        request: Request<AddNames, ___T>,
    ) -> impl Future<Output = ()>;
    fn add_handles(
        &mut self,
        request: Request<AddHandles, ___T>,
    ) -> impl Future<Output = ()>;
    fn set_options(
        &mut self,
        request: Request<SetOptions, ___T>,
    ) -> impl Future<Output = ()>;
}
A server handler for the Launcher protocol.

See Launcher for more details.

Required Methods

fn launch( &mut self, request: Request<Launch, ___T>, responder: Responder<Launch, ___T>, ) -> impl Future<Output = ()>

Creates and starts the process described by info.

After processing this message, the Launcher is reset to its initial state and is ready to launch another process.

process is present if, and only if, status is ZX_OK.

fn create_without_starting( &mut self, request: Request<CreateWithoutStarting, ___T>, responder: Responder<CreateWithoutStarting, ___T>, ) -> impl Future<Output = ()>

Creates the process described by info but does not start it.

After processing this message, the Launcher is reset to its initial state and is ready to launch another process.

The caller is responsible for calling zx_process_start using the data in ProcessStartData to actually start the process.

data is present if, and only if, status is ZX_OK.

fn add_args( &mut self, request: Request<AddArgs, ___T>, ) -> impl Future<Output = ()>

Adds the given arguments to the command-line for the process.

Calling this method multiple times concatenates the arguments.

fn add_environs( &mut self, request: Request<AddEnvirons, ___T>, ) -> impl Future<Output = ()>

Adds the given variables to the environment variables for the process.

Calling this method multiple times concatenates the variables.

fn add_names( &mut self, request: Request<AddNames, ___T>, ) -> impl Future<Output = ()>

Adds the given names to the namespace for the process.

The paths in the namespace must be non-overlapping. See https://fuchsia.dev/fuchsia-src/concepts/process/namespaces for details.

Calling this method multiple times concatenates the names.

fn add_handles( &mut self, request: Request<AddHandles, ___T>, ) -> impl Future<Output = ()>

Adds the given handles to the startup handles for the process.

Calling this method multiple times concatenates the handles.

fn set_options( &mut self, request: Request<SetOptions, ___T>, ) -> impl Future<Output = ()>

Sets the options with which the process is created.

Calling this method multiple times will overwrite the current options.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> LauncherLocalServerHandler<___T> for Local<___H>
where ___H: LauncherServerHandler<___T>, ___T: Transport,

Source

async fn launch( &mut self, request: Request<Launch, ___T>, responder: Responder<Launch, ___T>, )

Source

async fn create_without_starting( &mut self, request: Request<CreateWithoutStarting, ___T>, responder: Responder<CreateWithoutStarting, ___T>, )

Source

async fn add_args(&mut self, request: Request<AddArgs, ___T>)

Source

async fn add_environs(&mut self, request: Request<AddEnvirons, ___T>)

Source

async fn add_names(&mut self, request: Request<AddNames, ___T>)

Source

async fn add_handles(&mut self, request: Request<AddHandles, ___T>)

Source

async fn set_options(&mut self, request: Request<SetOptions, ___T>)

Implementors