pub trait ResolverServerHandler<___T: Transport = Channel> {
// Required method
fn resolve(
&mut self,
request: Request<Resolve, ___T>,
responder: Responder<Resolve, ___T>,
) -> impl Future<Output = ()> + Send;
}Expand description
A server handler for the Resolver protocol.
See Resolver for more details.
Required Methods
Sourcefn resolve(
&mut self,
request: Request<Resolve, ___T>,
responder: Responder<Resolve, ___T>,
) -> impl Future<Output = ()> + Send
fn resolve( &mut self, request: Request<Resolve, ___T>, responder: Responder<Resolve, ___T>, ) -> impl Future<Output = ()> + Send
Resolves the given name to an executable and an shared library
loader.
If present, the executable is suitable for use as the executable
property of LaunchInfo – in particular, it will have ZX_RIGHT_EXECUTE.
If present, the ldsvc is suitable for use as the PA_LDSVC_LOADER
handle when launching the process.
For example, the resolver might locate the given name inside a package
and return the executable binary from the package as well as a shared
library loader scoped to that package.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".